@@ -1,4 +1,4 @@
-//$Id: app-win.h,v 1.14 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: app-win.h,v 1.15 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,7 +32,7 @@ namespace Guikachu
     namespace GUI
     {
 	class AppWindow: public ResourceWindow,
-			 public SigC::Object
+			 public sigc::trackable
 	{
 	    Resources::Application *res;
 	    Gtk::Window            *window;
