@@ -1,4 +1,4 @@
-//$Id: bitmap-res-ops.cc,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-res-ops.cc,v 1.4 2004/09/23 16:21:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,8 +26,8 @@
 using namespace Guikachu;
 using namespace Guikachu::ResourceOps::BitmapOps;
 
-ImageChangeOp::ImageChangeOp (Resources::Bitmap   *bitmap,
-                              const Magick::Image &old_image_) :
+ImageChangeOp::ImageChangeOp (Resources::Bitmap                  *bitmap,
+                              const Resources::Bitmap::ImageData &old_image_) :
     manager (bitmap->get_manager ()),
     bitmap_serial (bitmap->get_serial ()),
     old_image (old_image_),
