@@ -1,4 +1,4 @@
-//$Id: bitmap-res.h,v 1.10 2004/08/20 18:22:17 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-res.h,v 1.13 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,8 @@
 
 #include "resource.h"
 
-#include <Magick++.h>
+#include <gdkmm/pixbuf.h>
+#include "io/io.h"
 
 namespace Guikachu
 {
@@ -39,7 +40,9 @@ namespace Guikachu
                 TYPE_COLOR_256,
 		TYPE_COLOR_16K
             };
-            
+
+	    typedef Glib::RefPtr<Gdk::Pixbuf> ImageData;
+	    
 	    Bitmap (ResourceManager *manager, const std::string &id, serial_t serial);
             
 	    Type get_type () const { return RESOURCE_BITMAP; };
@@ -48,14 +51,19 @@ namespace Guikachu
 	    Property<BitmapType>   bitmap_type;
 
             void load_file     (const Glib::ustring &uri);
-	    void save_file_bmp (const Glib::ustring &uri) const;
-            void set_image     (const Magick::Blob &blob);
-            void set_image     (const Magick::Image &image);
+	    void load_data     (const unsigned char *data, size_t len);
 
-            Magick::Image get_image () const { return image; };
+	    void save_file_bmp (const Glib::ustring &uri) const;
+            void save_data_png (unsigned char *&data, size_t &len) const;
+            void save_file_png (const Glib::ustring &uri) const;
+            
+            void set_image     (const ImageData &image);
+	    void clear_image   ();
+
+            ImageData get_image () const { return image; };
             
         private:
-            Magick::Image image;
+            ImageData image;
 	};
     }
 }
