@@ -1,4 +1,4 @@
-//$Id: bitmap-win.cc,v 1.13 2004/08/31 19:16:21 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-win.cc,v 1.15 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -118,8 +118,8 @@ bool GUI::BitmapWindow::delete_event_impl (GdkEventAny *e)
 
 void GUI::BitmapWindow::update_image ()
 {
-    Magick::Image image = res->get_image ();
-    if (!image.isValid ())
+    Resources::Bitmap::ImageData image = res->get_image ();
+    if (!image)
     {
         preview_pixmap.set ("");
         export_button->set_sensitive (false);
@@ -180,7 +180,7 @@ void GUI::BitmapWindow::load_image_cb ()
 
     if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
     {
-        Magick::Image old_image = res->get_image ();
+        Resources::Bitmap::ImageData old_image = res->get_image ();
         res->load_file (file_chooser.get_uri ());
         
         UndoOp *op = new ResourceOps::BitmapOps::ImageChangeOp (res, old_image);
@@ -199,17 +199,14 @@ void GUI::BitmapWindow::export_image_cb ()
     file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
     
     Gtk::FileFilter filter;
-    filter.set_name (_("Image files"));
-    filter.add_custom (Gtk::FILE_FILTER_MIME_TYPE, sigc::ptr_fun (BitmapWindow_Helpers::is_image_file));
+    filter.set_name (_("PNG files"));
+    filter.add_mime_type ("image/png");
     file_chooser.add_filter (filter);
-
-    // TODO: allow remote URI's
-    file_chooser.set_local_only (true);
+    file_chooser.set_local_only (false);
 
     if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
     {
         // TODO: Show a warning before overwriting files
-        Magick::Image image = res->get_image ();
-        image.write (file_chooser.get_filename ());
+        res->save_file_png (file_chooser.get_uri ());
     }
 }
