@@ -1,4 +1,4 @@
-//$Id: bitmapfamily-res-ops.cc,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-res-ops.cc,v 1.4 2004/09/23 16:21:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -112,9 +112,9 @@ Resources::BitmapFamily * BitmapFamilyHolder::get_resource () const
 }
 
 
-ImageChangeOp::ImageChangeOp (Resources::BitmapFamily       *res,
-                              Resources::Bitmap::BitmapType  type_,
-                              const Magick::Image           &old_image_) :
+ImageChangeOp::ImageChangeOp (Resources::BitmapFamily            *res,
+                              Resources::Bitmap::BitmapType       type_,
+                              const Resources::Bitmap::ImageData &old_image_) :
     BitmapFamilyHolder (res),
     type (type_),
     old_image (old_image_),
@@ -158,5 +158,5 @@ void ImageRemoveOp::undo ()
 void ImageRemoveOp::redo ()
 {
     Resources::BitmapFamily *res = get_resource ();
-    res->set_image (type, Magick::Image ());
+    res->set_image (type, Resources::Bitmap::ImageData ());
 }
