@@ -1,4 +1,4 @@
-//$Id: bitmapfamily-res.h,v 1.6 2004/08/20 18:22:17 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-res.h,v 1.9 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,7 @@
 #include "resource.h"
 #include "bitmap-res.h"
 
-#include "hash-map.h"
+#include <map>
 
 namespace Guikachu
 {
@@ -31,20 +31,26 @@ namespace Guikachu
 	class BitmapFamily: public Resource
 	{
 	    typedef Resources::Bitmap::BitmapType BitmapType;
-	    typedef std::hash_map<BitmapType, Magick::Image> image_map_t;
+	    typedef Resources::Bitmap::ImageData  ImageData;
+	    typedef std::map<BitmapType, ImageData> image_map_t;
 	    
 	public:
 	    BitmapFamily (ResourceManager *manager, const std::string &id, serial_t serial);
 
 	    Type get_type () const { return RESOURCE_BITMAPFAMILY; };
 	    void apply_visitor (ResourceVisitor &visitor) { visitor.visit_resource (this); };
-	    Magick::Image get_image (BitmapType type) const;
+	    ImageData get_image (BitmapType type) const;
 	    
 	    void load_file     (BitmapType type, const Glib::ustring &uri);
-	    void save_file_bmp (BitmapType type, const Glib::ustring &uri) const;
-            void set_image     (BitmapType type, const Magick::Blob &blob);
-            void set_image     (BitmapType type, const Magick::Image &image);
+	    void load_data     (BitmapType type, const unsigned char *data, size_t len);
 
+	    void save_file_bmp (BitmapType type, const Glib::ustring &uri) const;
+	    void save_data_png (BitmapType type, unsigned char *&data, size_t &len) const;
+	    void save_file_png (BitmapType type, const Glib::ustring &uri) const;
+            
+            void set_image     (BitmapType type, const ImageData &image);
+	    void clear_image   (BitmapType type);
+	    
 	private:
 	    image_map_t images;
 	};
