@@ -1,4 +1,4 @@
-//$Id: bitmapfamily-win.cc,v 1.9 2004/09/01 11:09:58 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-win.cc,v 1.11 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -134,7 +134,7 @@ void GUI::BitmapFamilyWindow::update ()
     window.set_title (title_buf);
     g_free (title_buf);
 
-    Magick::Image image = res->get_image (type);
+    Resources::Bitmap::ImageData image = res->get_image (type);
     
     Glib::RefPtr<Gdk::Pixbuf> pixbuf = FormEditor::render_bitmap (image, type);
 
@@ -151,12 +151,12 @@ void GUI::BitmapFamilyWindow::update ()
 
     if (type == Resources::Bitmap::TYPE_GREY_16)
     {
-        load_button->set_sensitive (!res->get_image (Resources::Bitmap::TYPE_COLOR_16).isValid ());
+        load_button->set_sensitive (!res->get_image (Resources::Bitmap::TYPE_COLOR_16));
     }
 
     if (type == Resources::Bitmap::TYPE_COLOR_16)
     {
-        load_button->set_sensitive (!res->get_image (Resources::Bitmap::TYPE_GREY_16).isValid ());
+        load_button->set_sensitive (!res->get_image (Resources::Bitmap::TYPE_GREY_16));
     }
     
     // Update the preview
@@ -219,25 +219,22 @@ void GUI::BitmapFamilyWindow::export_cb ()
     file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
     
     Gtk::FileFilter filter;
-    filter.set_name (_("Image files"));
-    filter.add_custom (Gtk::FILE_FILTER_MIME_TYPE, sigc::ptr_fun (BitmapWindow_Helpers::is_image_file));
+    filter.set_name (_("PNG files"));
+    filter.add_mime_type ("image/png");
     file_chooser.add_filter (filter);
-
-    // TODO: allow remote URI's
-    file_chooser.set_local_only (true);
+    file_chooser.set_local_only (false);
 
     if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
     {
         // TODO: Show a warning before overwriting files
-        Magick::Image image = res->get_image (type);
-        image.write (file_chooser.get_filename ());
+        res->save_file_png (type, file_chooser.get_uri ());
     }
 }
 
 void GUI::BitmapFamilyWindow::remove_cb ()
 {
     UndoOp *op = new ResourceOps::BitmapFamilyOps::ImageRemoveOp (res, type);
-    res->set_image (type, Magick::Image ());
+    res->clear_image (type);
     res->get_manager ()->get_undo_manager ().push (op);
 }
 
