@@ -1,4 +1,4 @@
-//$Id: bitmapfamily-win.h,v 1.4 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-win.h,v 1.5 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,7 +31,7 @@ namespace Guikachu
     namespace GUI
     {
 	class BitmapFamilyWindow: public ResourceWindow,
-				  public SigC::Object
+				  public sigc::trackable
 	{
 	    Resources::BitmapFamily       *res;
             Resources::Bitmap::BitmapType  type;
