@@ -1,4 +1,4 @@
-//$Id: edit-cut-and-paste.cc,v 1.9 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: edit-cut-and-paste.cc,v 1.10 2004/09/25 08:46:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -45,7 +45,7 @@ namespace
     struct
     {
 	std::string       target;
-	char             *buffer;
+	unsigned char    *buffer;
 	GnomeVFSFileSize  length;
 	
 	void reset () {
