@@ -1,6 +1,6 @@
-//$Id: edit-ops.h,v 1.4 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-
+//$Id: edit-ops.h,v 1.6 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -37,12 +37,12 @@ namespace Guikachu
 	    std::string     id;
 	    StorageNode     node;
 
-	    std::string op_label;
+	    Glib::ustring    op_label;
 	    
 	public:
 	    PasteResourceOp (Resource *pasted_resource);
 
-	    std::string get_label () const { return op_label; };
+	    Glib::ustring get_label () const { return op_label; };
 
 	    void undo ();
 	    void redo ();
@@ -57,7 +57,7 @@ namespace Guikachu
 	    PasteResourcesOp (const std::list<Resource*> &pasted_resources);
 	    virtual ~PasteResourcesOp ();
 
-	    std::string get_label () const;
+	    Glib::ustring get_label () const;
 
 	    void undo ();
 	    void redo ();
@@ -73,12 +73,12 @@ namespace Guikachu
 	    std::string   id;
 	    StorageNode   node;
 
-	    std::string op_label;
+	    Glib::ustring op_label;
 	    
 	public:
 	    PasteWidgetOp (Widget *pasted_resource);
 
-	    std::string get_label () const { return op_label; };
+	    Glib::ustring get_label () const { return op_label; };
 
 	    void undo ();
 	    void redo ();
@@ -87,14 +87,14 @@ namespace Guikachu
 	class PasteWidgetsOp: public UndoOp
 	{
 	    typedef std::list<PasteWidgetOp*> paste_ops_t;
-	    paste_ops_t paste_ops;
-	    std::string op_label;
+	    paste_ops_t   paste_ops;
+	    Glib::ustring op_label;
 	    
 	public:
 	    PasteWidgetsOp (const std::list<Widget*> &pasted_resources);
 	    virtual ~PasteWidgetsOp ();
 
-	    std::string get_label () const { return op_label; };
+	    Glib::ustring get_label () const { return op_label; };
 
 	    void undo ();
 	    void redo ();
