@@ -1,4 +1,4 @@
-//$Id: canvas-grip.h,v 1.5 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: canvas-grip.h,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,9 +47,9 @@ namespace Guikachu
 
 		void set_position (gdouble x, gdouble y);
 		
-		SigC::Signal0<void> drag_begin;
-		SigC::Signal2<void, int, int> drag_motion;
-		SigC::Signal0<void> drag_end;
+		sigc::signal0<void> drag_begin;
+		sigc::signal2<void, int, int> drag_motion;
+		sigc::signal0<void> drag_end;
 
 	    private:
 		void canvas_event_cb  (GdkEvent *event);
