@@ -1,4 +1,4 @@
-//$Id: checkbox-canvas.cc,v 1.32 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-canvas.cc,v 1.33 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,19 +29,12 @@ CheckboxCanvasItem::CheckboxCanvasItem (Widgets::Checkbox  *widget_,
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
-    widget (widget_),
-    group (0)
+    widget (widget_)
 {
-    update ();
 }
 
-void CheckboxCanvasItem::update ()
+void CheckboxCanvasItem::draw (FooCanvasmm::Group &group) const
 {
-    if (group)
-	delete group;
-
-    group = new FooCanvasmm::Group (*draw_group, 0, 0);
-    
     int width = widget->get_width ();
     int height = widget->get_height ();
 
@@ -53,7 +46,7 @@ void CheckboxCanvasItem::update ()
 
     // Background transparent rectangle to get mouse events inside
     // "hollow" areas
-    FormEditor::draw_rectangle (*group, x1, y1, x2, y2);
+    FormEditor::draw_rectangle (group, x1, y1, x2, y2);
 
     int text_x = x1 + 17;
     int text_y = y1;
@@ -64,7 +57,7 @@ void CheckboxCanvasItem::update ()
     null_string += '\0';
     
     // Font #4 is Symbol11, and \001 and \000 are the checked/unchecked boxes
-    draw_text (*group, widget->toggled ? "\001" : null_string, get_font (4),
+    draw_text (group, widget->toggled ? "\001" : null_string, get_font (4),
 	       get_foreground_color (widget->usable),
 	       x1, text_y, 0, height,
 	       Gtk::ANCHOR_WEST);
@@ -72,14 +65,12 @@ void CheckboxCanvasItem::update ()
     // Render text label
     if (width > 18)
     {
-	draw_text (*group,
+	draw_text (group,
 		   widget->text, get_font (widget->font),
 		   get_foreground_color (widget->usable),
 		   text_x, text_y, width - 16, height,
 		   Gtk::ANCHOR_WEST);
     }
-    
-    set_canvas_item (group);
 }
 
 void CheckboxCanvasItem::get_bounds (int &x1, int &y1,
