@@ -1,4 +1,4 @@
-//$Id: colorpalette.cc,v 1.7 2004/08/20 13:33:44 cactus Exp $ -*- c++ -*-
+//$Id: colorpalette.cc,v 1.8 2004/09/23 16:21:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,7 +47,8 @@ namespace
             }
         
         Color get_nearest_color (const Color &color) const;
-        void  dither_pixels (const Glib::RefPtr<Gdk::Pixbuf> &pixbuf, guint8 *pixels) const;
+        void  dither_pixels (const Guikachu::Resources::Bitmap::ImageData &image, 
+			     const Glib::RefPtr<Gdk::Pixbuf>              &pixbuf) const;
     };
 } // Anonymous namespace
     
@@ -72,17 +73,22 @@ Color ColorPalette::get_nearest_color (const Color &color) const
     return palette[min_i];
 }
 
-void ColorPalette::dither_pixels (const Glib::RefPtr<Gdk::Pixbuf> &pixbuf, guint8 *pixels) const
+void ColorPalette::dither_pixels (const Guikachu::Resources::Bitmap::ImageData &image, 
+				  const Glib::RefPtr<Gdk::Pixbuf>              &pixbuf) const
 {
     guint8 *dest_pixels = pixbuf->get_pixels ();
     int width = pixbuf->get_width ();
     int height = pixbuf->get_height ();
     int rowstride = pixbuf->get_rowstride ();
 
+    guint8 *src_pixels = image->get_pixels ();
+    int src_rowstride = image->get_rowstride ();
+    int src_bpp = image->get_has_alpha () ? 4 : 3;
+
     for (int y = 0; y < height; ++y)
         for (int x = 0; x < width; ++x)
         {
-            guint8 *start = pixels + (y * width * 3) + (x * 3);
+            guint8 *start = src_pixels + (y * src_rowstride) + (x * src_bpp);
             Color c = { start[0], start[1], start[2] };
 
             c = get_nearest_color (c);
@@ -188,9 +194,9 @@ namespace
     
 } // Anonymous namespace
 
-void FormEditor::dither_pixels (Resources::Bitmap::BitmapType    type,
-                                const Glib::RefPtr<Gdk::Pixbuf> &pixbuf,
-                                guint8                          *pixels)
+void FormEditor::dither_pixels (Resources::Bitmap::BitmapType       type,
+				const Resources::Bitmap::ImageData &image,
+				Glib::RefPtr<Gdk::Pixbuf>          &pixbuf)
 {
     const ColorPalette *palette = 0;
     
@@ -216,9 +222,10 @@ void FormEditor::dither_pixels (Resources::Bitmap::BitmapType    type,
 
     case Resources::Bitmap::TYPE_COLOR_16K:
 	// No dithering is done for high-color images
+	pixbuf = image;
 	break;
     }
 
     if (palette)
-	palette->dither_pixels (pixbuf, pixels);
+	palette->dither_pixels (image, pixbuf);
 }
