@@ -1,4 +1,4 @@
-//$Id: form-canvas.h,v 1.11 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: form-canvas.h,v 1.12 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -61,8 +61,8 @@ namespace Guikachu
 
 		FooCanvasmm::Group *get_widget_group ();
 
-		SigC::Signal2<void, guint, guint32> context_menu;
-		SigC::Signal1<void, bool> selected;
+		sigc::signal2<void, guint, guint32> context_menu;
+		sigc::signal1<void, bool> selected;
 		
 	    private:
 		/* Drawing methods */
