@@ -1,4 +1,4 @@
-//$Id: form-editor-canvas.h,v 1.13 2004/09/04 12:00:06 cactus Exp $ -*- c++ -*-
+//$Id: form-editor-canvas.h,v 1.14 2004/09/23 16:21:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,8 +42,8 @@ namespace Guikachu
                                            Gtk::AnchorType     anchor = Gtk::ANCHOR_CENTER,
                                            bool                multi_line = false);
             
-            Glib::RefPtr<Gdk::Pixbuf> render_bitmap (const Magick::Image           &image,
-                                                     Resources::Bitmap::BitmapType  bitmap_type);
+            Glib::RefPtr<Gdk::Pixbuf> render_bitmap (const Resources::Bitmap::ImageData &image,
+                                                     Resources::Bitmap::BitmapType       bitmap_type);
 
 	    Glib::RefPtr<Gdk::Pixbuf> render_bitmapref (const Properties::ResourceRef &ref_prop,
                                                         bool                           color);
@@ -64,15 +64,15 @@ namespace Guikachu
                                              int                 x = 0,
                                              int                 y = 0);
             
-            FooCanvasmm::Item * draw_bitmap (FooCanvasmm::Group            &group,
-                                             const Magick::Image           &image,
-                                             Resources::Bitmap::BitmapType  bitmap_type,
-                                             const Gdk::Color              &background_color,
-                                             int                            x,
-                                             int                            y,
-                                             int                            clip_width = 0,
-                                             int                            clip_height = 0,
-                                             Gtk::AnchorType                anchor = Gtk::ANCHOR_NW);
+            FooCanvasmm::Item * draw_bitmap (FooCanvasmm::Group                 &group,
+                                             const Resources::Bitmap::ImageData &image,
+                                             Resources::Bitmap::BitmapType       bitmap_type,
+                                             const Gdk::Color                   &background_color,
+                                             int                                 x,
+                                             int                                 y,
+                                             int                                 clip_width = 0,
+                                             int                                 clip_height = 0,
+                                             Gtk::AnchorType                     anchor = Gtk::ANCHOR_NW);
 
             FooCanvasmm::Item * draw_bitmapref (FooCanvasmm::Group            &group,
                                                 const Properties::ResourceRef &ref_prop,
