@@ -1,4 +1,4 @@
-//$Id: formbitmap-canvas.h,v 1.5 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: formbitmap-canvas.h,v 1.6 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,15 +31,14 @@ namespace Guikachu
 	    class FormBitmapCanvasItem: public WidgetCanvasItem
 	    {
 		Widgets::FormBitmap *widget;
-		FooCanvasmm::Group  *group;
                 
 	    public:
 		FormBitmapCanvasItem (Widgets::FormBitmap *res,
                                       FooCanvasmm::Group  &parent_group);
 
 	    protected:
-		virtual void update ();
-                void draw_placeholder ();
+		virtual void draw (FooCanvasmm::Group &group) const;
+                void draw_placeholder (FooCanvasmm::Group &group) const;
 	    };
 	}
     }
