@@ -1,4 +1,4 @@
-//$Id: formbitmap.h,v 1.5 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: formbitmap.h,v 1.6 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 
 #include "widget.h"
 #include "widget-ref.h"
+#include "usable.h"
 
 #include <sigc++/connection.h>
 
@@ -28,7 +29,8 @@ namespace Guikachu
 {
     namespace Widgets
     {
-	class FormBitmap: public Widget
+	class FormBitmap: public Widget,
+                          public Usable
 	{
 	    VSignal          bitmap_id_changed;
 	    sigc::connection bitmap_changed_conn;
@@ -40,7 +42,6 @@ namespace Guikachu
 	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
 	    
 	    Properties::ResourceRef bitmap_id;
-	    Property<bool>          usable;
 
             // Virtual methods from FormElement parent class
             int get_width  () const;
