@@ -1,4 +1,4 @@
-//$Id: gadget-canvas.cc,v 1.16 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: gadget-canvas.cc,v 1.17 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -29,19 +29,12 @@ GadgetCanvasItem::GadgetCanvasItem (Widgets::Gadget    *widget_,
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
-    widget (widget_),
-    group (0)
+    widget (widget_)
 {
-    update ();
 }
 
-void GadgetCanvasItem::update ()
+void GadgetCanvasItem::draw (FooCanvasmm::Group &group) const
 {
-    if (group)
-	delete group;
-    
-    group = new FooCanvasmm::Group (*draw_group, 0, 0);
-
     int x1 = widget->x;
     int x2 = x1 + widget->width;
     int y1 = widget->y;
@@ -52,9 +45,7 @@ void GadgetCanvasItem::update ()
 	Gdk::Bitmap::create (stipple_bits, 3, 3);
     
     using namespace FooCanvasmm::Properties;
-    *(draw_rectangle (*group, x1, y1, x2, y2))
+    *(draw_rectangle (group, x1, y1, x2, y2))
 	<< fill_stipple (stipple)
 	<< fill_color (get_foreground_color (widget->usable));
-
-    set_canvas_item (group);
 }
