@@ -1,4 +1,4 @@
-//$Id: gadget.h,v 1.14 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: gadget.h,v 1.15 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,12 +21,14 @@
 
 #include "widget.h"
 #include "resizeable-widget.h"
+#include "usable.h"
 
 namespace Guikachu
 {
     namespace Widgets
     {
 	class Gadget: public Widget,
+                      public Usable,
 		      public ResizeableWidget
 	{
 	public:
@@ -34,8 +36,6 @@ namespace Guikachu
 	    
 	    Type get_type () const { return WIDGET_GADGET; };
 	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
-	    
-	    Property<bool> usable;
 	};
     }
 }
