@@ -1,4 +1,4 @@
-//$Id: glyph.cc,v 1.11 2004/08/31 12:50:40 cactus Exp $ -*- c++ -*-
+//$Id: glyph.cc,v 1.12 2004/09/03 13:29:12 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,7 +28,7 @@ using namespace Guikachu::GUI::FormEditor;
 Glyph::Glyph (int height, int ascent):
     width (5)
 {
-    bitmap = new bool*[height];
+    bitmap = g_new0 (bool, height * width);
     
     for (int i = 0; i < height; i++)
     {
@@ -40,14 +40,14 @@ Glyph::Glyph (int height, int ascent):
 
     for (int x = 0; x < width; x++)
     {
-	bitmap[y1][x] = true;
-	bitmap[y2][x] = true;
+	bitmap[y1 * width + x] = true;
+	bitmap[y2 * width + x] = true;
     }
 
     for (int y = y1; y < y2; y++)
     {
-	bitmap[y][0] = true;
-	bitmap[y][4] = true;
+	bitmap[y * width + 0] = true;
+	bitmap[y * width + 4] = true;
     }
 }
 
@@ -56,8 +56,7 @@ Glyph::Glyph (std::istream &stream,
     width (0),
     offset (0),
     bitmap (0)
-{
-    
+{    
     std::string curr_line;
     bool        in_bitmap = true;
     bool        in_header = true;
@@ -98,12 +97,11 @@ Glyph::Glyph (std::istream &stream,
 
 	if (!width)
 	    width = curr_line.length ();
-
-	bitmap = (bool**) g_realloc (bitmap, (row + 1) * sizeof (bool*));
-	bitmap[row] = new bool[width];
-
+	
+	bitmap = (bool*) g_realloc (bitmap, ((row + 1) * width) * sizeof (bool));
+	
 	for (int i = 0; i < width; i++)
-	    bitmap[row][i] = (curr_line[i] == GLYPH_ON);
+	    bitmap[row * width  + i] = (curr_line[i] == GLYPH_ON);
 	
 	getline (stream, curr_line);
 	row++;
@@ -113,3 +111,9 @@ Glyph::Glyph (std::istream &stream,
 	height = row;
 }
 
+Glyph::~Glyph ()
+{
+#if 0
+    g_free (bitmap);
+#endif
+}
