@@ -1,4 +1,4 @@
-//$Id: graffiti-canvas.cc,v 1.14 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-canvas.cc,v 1.15 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,21 +31,14 @@ GraffitiCanvasItem::GraffitiCanvasItem (Widgets::Graffiti  *widget_,
 					FooCanvasmm::Group &parent_group):
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
-    widget (widget_),
-    group (0)
+    widget (widget_)
 {
-    update ();
 }
 
-void GraffitiCanvasItem::update ()
+void GraffitiCanvasItem::draw (FooCanvasmm::Group &group) const
 {
-    if (group)
-	delete group;
+    Glib::RefPtr<Gdk::Pixbuf> pixbuf =
+        Gdk::Pixbuf::create_from_xpm_data (graffiti_canvas_xpm);
     
-    group = new FooCanvasmm::Group (*draw_group, 0, 0);
-
-    Glib::RefPtr<Gdk::Pixbuf> pixbuf = Gdk::Pixbuf::create_from_xpm_data (graffiti_canvas_xpm);
-    new FooCanvasmm::Pixbuf (*group, widget->x, widget->y, pixbuf);
-
-    set_canvas_item (group);
+    new FooCanvasmm::Pixbuf (group, widget->x, widget->y, pixbuf);
 }
