@@ -1,4 +1,4 @@
-//$Id: label.cc,v 1.36 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: label.cc,v 1.37 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,8 +27,8 @@ Label::Label (Resources::Form   *owner,
 	      const std::string &id,
 	      serial_t           serial):
     Widget (owner, id, serial),
-    Textual (changed, id),
-    usable (changed, true)
+    Usable (changed),
+    Textual (changed, id)
 {
 }
 
