@@ -1,4 +1,4 @@
-//$Id: list-prop.h,v 1.6 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.h,v 1.7 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,7 @@
 #include "list.h"
 #include "widget-prop.h"
 
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 
 namespace Guikachu
 {
@@ -31,7 +31,7 @@ namespace Guikachu
 	namespace FormEditor
 	{
 	    class ListProperties: public WidgetProperties,
-				  public SigC::Object
+				  public sigc::trackable
 	    {
 		Gtk::Widget *property_editor;
 	    public:
