@@ -1,4 +1,4 @@
-//$Id: popup-trigger.cc,v 1.30 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.31 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,15 +26,16 @@ using namespace Guikachu::GUI::FormEditor;
 PopupTrigger::PopupTrigger (Resources::Form   *owner,
 			    const std::string &id,
 			    serial_t           serial):
-    Widget (owner, id, serial),
     ResizeableWidget (changed),
+    Widget (owner, id, serial),
     AutoWidth (changed),
     AutoHeight (changed),
+    Usable (changed),
+    Disabled (changed),
     Textual (changed, id),
     Graphical (changed, owner->get_manager ()),
 
     list_id (changed, owner),
-    usable (changed, true),
     anchor_right (changed, false)
 {
 }
