@@ -1,4 +1,4 @@
-//$Id: pushbutton-canvas.h,v 1.12 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-canvas.h,v 1.13 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,14 +33,13 @@ namespace Guikachu
 					public ResizeableCanvasItem
 	    {
 		Widgets::PushButton *widget;
-		FooCanvasmm::Group  *group;
 		
 	    public:
 		PushButtonCanvasItem (Widgets::PushButton *widget,
 				      FooCanvasmm::Group  &parent_group);
 
 	    protected:
-		virtual void update ();
+		virtual void draw (FooCanvasmm::Group &group) const;
 		virtual void get_bounds (int &x1, int &y1,
 					 int &x2, int &y2);
 	    };
