@@ -1,4 +1,4 @@
-//$Id: scrollbar-canvas.h,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-canvas.h,v 1.9 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,12 +33,13 @@ namespace Guikachu
 				       public ResizeableCanvasItem
 	    {
 		Widgets::ScrollBar *widget;
-		FooCanvasmm::Group *group;
+
 	    public:
 		ScrollBarCanvasItem (Widgets::ScrollBar *widget,
 				     FooCanvasmm::Group &parent_group);
+
 	    protected:
-		virtual void update ();
+		virtual void draw (FooCanvasmm::Group &group) const;
 	    };
 	}
     }
