@@ -1,4 +1,4 @@
-//$Id: selector-trigger-prop.cc,v 1.17 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-prop.cc,v 1.18 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,11 +22,11 @@
 #include <libgnome/libgnome.h>
 
 #include "auto-resizeable-prop.h"
+#include "usable-prop.h"
+#include "disabled-prop.h"
 #include "textual-prop.h"
 #include "graphical-prop.h"
 
-#include "widgets/entry.h"
-#include "widgets/num-entry.h"
 #include "widgets/togglebutton.h"
 #include "widgets/propertytable.h"
 
@@ -52,13 +52,6 @@ SelectorTriggerProperties::SelectorTriggerProperties (SelectorTrigger *res):
     /* Bitmaps */
     GraphicalProperties::add_controls (res, *proptable);
     
-    /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (
-	res->usable,
-	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
-    proptable->add (_("_Usable:"), *manage (control),
-		    _("Non-usable widgets are not rendered by default"));
-
     /* Anchor right */
     control = new GUI::PropertyEditors::ToggleButton (
 	res->anchor_right,
@@ -67,6 +60,10 @@ SelectorTriggerProperties::SelectorTriggerProperties (SelectorTrigger *res):
 		    _("Keep right aligned when changing label "
 		      "text at run-time"));
     
+    /* Usable */
+    UsableProperties::add_controls (res, *proptable);
+    DisabledProperties::add_controls (res, *proptable);
+
     /* Separator */
     proptable->add_separator ();
 
