@@ -1,4 +1,4 @@
-//$Id: table-canvas.cc,v 1.22 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: table-canvas.cc,v 1.23 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -56,19 +56,12 @@ TableCanvasItem::TableCanvasItem (Widgets::Table     *widget_,
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
-    widget (widget_),
-    group (0)
+    widget (widget_)
 {
-    update ();
 }
 
-void TableCanvasItem::update ()
+void TableCanvasItem::draw (FooCanvasmm::Group &group) const
 {
-    if (group)
-	delete group;
-
-    group = new FooCanvasmm::Group (*draw_group, 0, 0);
-
     const std::vector<int> &columns = widget->column_width;
 
     /* Column separators */
@@ -80,7 +73,7 @@ void TableCanvasItem::update ()
     int y1 = widget->y;
     int y2 = y1 + std::min (height, widget->get_height ());
     
-    draw_table_line (*group, color, x1, y1, x1, y2);
+    draw_table_line (group, color, x1, y1, x1, y2);
 
     int num_columns = widget->num_columns;
     for (int i = 0; i < num_columns; i++)
@@ -89,13 +82,13 @@ void TableCanvasItem::update ()
 	int line_x = x1 + width;
 
 	if (width <= widget->get_width ())
-	    draw_table_line (*group, color, line_x, y1, line_x, y2);
+	    draw_table_line (group, color, line_x, y1, line_x, y2);
     }
     
     int x2 = x1 + std::min (width, widget->get_width ());
     
     /* Row separators */
-    draw_table_line (*group, color, x1, y1, x2, y1);
+    draw_table_line (group, color, x1, y1, x2, y1);
     const int row_step = 11;
     int row_y = 0;
     for (int i = 0; i < widget->num_rows; i++)
@@ -104,11 +97,9 @@ void TableCanvasItem::update ()
 	if (row_y > widget->get_height ())
 	    break;
 	
-	draw_table_line (*group, color, x1, y1 + row_y, x2, y1 + row_y);
+	draw_table_line (group, color, x1, y1 + row_y, x2, y1 + row_y);
     }
 
     // Draw background (to make it clickable)
-    draw_rectangle (*group, x1, y1, x1 + widget->get_width (), y1 + widget->get_height ());
-
-    set_canvas_item (group);
+    draw_rectangle (group, x1, y1, x1 + widget->get_width (), y1 + widget->get_height ());
 }
