@@ -1,4 +1,4 @@
-//$Id: text-field-canvas.cc,v 1.18 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.cc,v 1.19 2004/06/12 16:33:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,19 +31,12 @@ TextFieldCanvasItem::TextFieldCanvasItem (Widgets::TextField *widget_,
     CanvasItem (widget_, parent_group),
     WidgetCanvasItem (widget_, parent_group),
     ResizeableCanvasItem (widget_, parent_group, new WidgetOps::ResizeOpFactory (widget_)),
-    widget (widget_),
-    group (0)
+    widget (widget_)
 {
-    update ();
 }
 
-void TextFieldCanvasItem::update ()
+void TextFieldCanvasItem::draw (FooCanvasmm::Group &group) const
 {   
-    if (group)
-	delete group;
-    
-    group = new FooCanvasmm::Group (*draw_group, 0, 0);
-
     const Font &font = get_font (widget->font);
     int height = widget->get_height ();
     int width = widget->get_width ();
@@ -57,7 +50,7 @@ void TextFieldCanvasItem::update ()
     int y = widget->y + 1;
     
     /* Draw background */
-    draw_rectangle (*group, x, y, x + width, y + height);
+    draw_rectangle (group, x, y, x + width, y + height);
 
     /* Draw underlines if enabled */
     if (widget->underline)
@@ -78,14 +71,12 @@ void TextFieldCanvasItem::update ()
 	    ul_points.push_back (FooCanvasmm::Point (x + width, underline_y));
 
 	    using namespace FooCanvasmm::Properties;
-	    *(new FooCanvasmm::Line (*group, ul_points))
+	    *(new FooCanvasmm::Line (group, ul_points))
 		<< fill_stipple (stipple)
 		<< width_units (1.0)
 		<< fill_color (get_foreground_color (widget->usable));
 	}
     }
-    
-    set_canvas_item (group);
 }
 
 void TextFieldCanvasItem::get_bounds (int &x1, int &y1,
