@@ -1,4 +1,4 @@
-//$Id: text-field-prop.cc,v 1.18 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: text-field-prop.cc,v 1.19 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,6 +23,8 @@
 
 #include "resizeable-prop.h"
 #include "auto-resizeable-prop.h"
+#include "usable-prop.h"
+#include "disabled-prop.h"
 
 #include "widgets/num-entry.h"
 #include "widgets/togglebutton.h"
@@ -45,13 +47,6 @@ TextFieldProperties::TextFieldProperties (TextField *res):
     /* Resource ID */
     add_general_controls (*proptable);
 
-    /* Usable */
-    control = new GUI::PropertyEditors::ToggleButton (
-	res->usable,
-	new PropChangeOpFactory<bool> (_("Toggle usable state of %s"), res, res->usable, false));
-    proptable->add (_("_Usable:"), *manage (control),
-		    _("Non-usable widgets are not rendered by default"));
-
     /* Font */
     control = new GUI::PropertyEditors::FontCombo (
 	res->font,
@@ -128,6 +123,10 @@ TextFieldProperties::TextFieldProperties (TextField *res):
 		      "if the text entered is longer than the field's "
 		      "visible size"));
     
+    /* Usable */
+    UsableProperties::add_controls (res, *proptable);
+    DisabledProperties::add_controls (res, *proptable);
+    
     /* Separator */
     proptable->add_separator ();
 
