@@ -1,4 +1,4 @@
-//$Id: widget-factory-canvas.h,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: widget-factory-canvas.h,v 1.7 2004/09/04 12:00:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,11 +30,11 @@
 #include "form-editor/gadget-canvas.h"
 #include "form-editor/graffiti-canvas.h"
 #include "form-editor/label-canvas.h"
-#include "form-editor/label-canvas.h"
 #include "form-editor/list-canvas.h"
 #include "form-editor/popup-trigger-canvas.h"
 #include "form-editor/pushbutton-canvas.h"
 #include "form-editor/scrollbar-canvas.h"
+#include "form-editor/slider-canvas.h"
 #include "form-editor/selector-trigger-canvas.h"
 #include "form-editor/table-canvas.h"
 #include "form-editor/text-field-canvas.h"
@@ -96,6 +96,7 @@ namespace Guikachu
 		GUIKACHU_WIDGET_CANVAS_VISIT(List);
 		GUIKACHU_WIDGET_CANVAS_VISIT(PopupTrigger);
 		GUIKACHU_WIDGET_CANVAS_VISIT(ScrollBar);
+		GUIKACHU_WIDGET_CANVAS_VISIT(Slider);
 		GUIKACHU_WIDGET_CANVAS_VISIT(TextField);
 		GUIKACHU_WIDGET_CANVAS_VISIT(Table);
 		GUIKACHU_WIDGET_CANVAS_VISIT(FormBitmap);
