@@ -1,4 +1,4 @@
-//$Id: form-win-widgettree.cc,v 1.3 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: form-win-widgettree.cc,v 1.6 2004/06/27 11:06:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,11 @@
 #include "form-win-widgettree.h"
 
 #include "form-editor/widget-util.h"
+#include "form-editor/widget-util-gui.h"
+#include "resource-util-gui.h"
+
+#include "cellrenderer-icontext.h"
+#include "cellrenderer-indent.h"
 
 #include <gdk/gdkkeysyms.h>
 
@@ -32,32 +37,33 @@ WidgetTreeWrapper::WidgetTreeWrapper (Gtk::TreeView    &treeview_,
     menu_block (false)
 {
     Gtk::TreeModel::ColumnRecord cols;
-    cols.add (col_label);
     cols.add (col_widget);
     
     treestore = Gtk::TreeStore::create (cols);
     treeview.set_model (treestore);
-    
-    treeview.append_column ("", col_label);
+
     treeview.set_headers_visible (false);
+
+    CellRendererIndent<CellRendererIconText>::setup_view (
+        treeview, "", sigc::mem_fun (*this, &WidgetTreeWrapper::cell_label_cb));
     
     // Create root item: the form itself
     root_tree = *(treestore->append ());
     root_tree[col_widget] = 0;
 
-    form->changed.connect (SigC::slot (*this, &WidgetTreeWrapper::form_changed_cb));
+    form->changed.connect (sigc::mem_fun (*this, &WidgetTreeWrapper::form_changed_cb));
     form_changed_cb ();
     
-    form->widget_created.connect (SigC::slot (*this, &WidgetTreeWrapper::widget_created_cb));
-    form->widget_removed.connect (SigC::slot (*this, &WidgetTreeWrapper::widget_removed_cb));
+    form->widget_created.connect (sigc::mem_fun (*this, &WidgetTreeWrapper::widget_created_cb));
+    form->widget_removed.connect (sigc::mem_fun (*this, &WidgetTreeWrapper::widget_removed_cb));
 
     treeview.get_selection ()->set_select_function (
-	SigC::slot (*this, &WidgetTreeWrapper::selection_changed_cb));
+	sigc::mem_fun (*this, &WidgetTreeWrapper::selection_changed_cb));
     
     // Create tree items for existing widgets
     const std::set<Guikachu::Widget*> widgets = form->get_widgets ();
     std::for_each (widgets.begin (), widgets.end (),
-		   SigC::slot (*this, &WidgetTreeWrapper::widget_created_cb));
+		   sigc::mem_fun (*this, &WidgetTreeWrapper::widget_created_cb));
 
     treeview.expand_all ();
 
@@ -66,9 +72,32 @@ WidgetTreeWrapper::WidgetTreeWrapper (Gtk::TreeView    &treeview_,
 
     treeview.add_events (Gdk::BUTTON_PRESS_MASK | Gdk::KEY_PRESS_MASK);
     treeview.signal_button_press_event ().connect_notify (
-	SigC::slot (*this, &WidgetTreeWrapper::button_press_cb));
+	sigc::mem_fun (*this, &WidgetTreeWrapper::button_press_cb));
     treeview.signal_key_press_event ().connect (
-	SigC::bind_return (SigC::slot (*this, &WidgetTreeWrapper::key_press_cb), false));        
+	sigc::bind_return (sigc::mem_fun (*this, &WidgetTreeWrapper::key_press_cb), false));        
+}
+
+void WidgetTreeWrapper::cell_label_cb (Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter) const
+{
+    CellRendererIconText *cell_icontext = dynamic_cast<CellRendererIconText*> (cell);
+    g_return_if_fail (cell_icontext);
+    
+    Glib::ustring label;
+    Glib::RefPtr<Gdk::Pixbuf> pixbuf;
+    
+    Guikachu::Widget *widget = (*iter)[col_widget];
+
+    if (widget)
+    {
+        label = widget->id;
+        pixbuf = Widgets::get_type_pixbuf (widget->get_type ());
+    } else {
+        label = form->id;
+        pixbuf = Resources::get_type_pixbuf (Resources::RESOURCE_FORM);
+    }
+
+    cell_icontext->property_text () = label;
+    cell_icontext->property_pixbuf () = pixbuf;
 }
 
 void WidgetTreeWrapper::widget_removed_cb (Guikachu::Widget *widget)
@@ -83,29 +112,26 @@ void WidgetTreeWrapper::widget_removed_cb (Guikachu::Widget *widget)
 void WidgetTreeWrapper::widget_created_cb (Guikachu::Widget *widget)
 {
     Gtk::TreeRow row = *(treestore->append (root_tree.children ()));
-    row[col_label] = Glib::ustring (widget->id);
     row[col_widget] = widget;
 
     row_map[widget] = row;
     
-    widget->changed.connect (SigC::bind (
-	SigC::slot (*this, &WidgetTreeWrapper::widget_changed_cb), row));
-    widget->selected.connect (SigC::bind (
-	SigC::slot (*this, &WidgetTreeWrapper::widget_selected_cb), widget));
+    widget->changed.connect (sigc::bind (
+	sigc::mem_fun (*this, &WidgetTreeWrapper::widget_changed_cb), row));
+    widget->selected.connect (sigc::bind (
+	sigc::mem_fun (*this, &WidgetTreeWrapper::widget_selected_cb), widget));
     
     treeview.expand_all ();
 }
 
 void WidgetTreeWrapper::widget_changed_cb (Gtk::TreeRow row)
 {
-    Guikachu::Widget *widget = row[col_widget];
-    
-    row[col_label] = Glib::ustring (widget->id);
+    treestore->row_changed (treestore->get_path (row), row);
 }
 
 void WidgetTreeWrapper::form_changed_cb ()
 {
-    root_tree[col_label] = Glib::ustring (form->id);
+    treestore->row_changed (treestore->get_path (root_tree), root_tree);
 }
 
 void WidgetTreeWrapper::widget_selected_cb (bool selected,
@@ -182,7 +208,7 @@ void WidgetTreeWrapper::button_press_cb (GdkEventButton *e)
         {
             menu_block = true;
             Glib::signal_idle ().connect (
-                SigC::bind_return (SigC::bind (SigC::slot (reset_menu_block), &menu_block), false));
+                sigc::bind_return (sigc::bind (sigc::ptr_fun (reset_menu_block), &menu_block), false));
         }
             
 	Gtk::TreeModel::iterator iter = treestore->get_iter (path);
@@ -198,7 +224,7 @@ void WidgetTreeWrapper::button_press_cb (GdkEventButton *e)
 namespace
 {
     template<typename T, typename Container = std::list<T> >
-    class SelectionCollector: public SigC::Object
+    class SelectionCollector: public sigc::trackable
     {
     public:
         typedef T                               element_t;
@@ -219,18 +245,16 @@ namespace
 void WidgetTreeWrapper::key_press_cb (GdkEventKey *e)
 {
     Guikachu::Widget *widget = 0;
+
+    Gtk::TreeView::Selection::ListHandle_Path items = treeview.get_selection ()->get_selected_rows ();
     
-    typedef SelectionCollector<Guikachu::Widget*> collector_t;
-    typedef collector_t::container_t              collector_list_t;
-
-    collector_t collector (col_widget);
-    treeview.get_selection ()->selected_foreach (SigC::slot (collector, &collector_t::selection_cb));
-    collector_list_t items = collector.get_items ();
-
     // It doesn't really matter which widget we select when more than
     // one are selected
     if (items.size ())
-        widget = items.front ();
+    {
+        const Gtk::TreePath &path = *(items.begin ());
+        widget = (*treestore->get_iter (path))[col_widget];
+    }
 
     switch (e->keyval)
     {
