@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.40 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.41 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -45,7 +45,7 @@ namespace Guikachu
 	}
 	
 	class FormWindow: public ResourceWindow,
-			  public SigC::Object
+			  public sigc::trackable
 	{
 	    Resources::Form *res;
 	    
@@ -71,7 +71,7 @@ namespace Guikachu
 	    typedef std::set<Widget*> selection_t;
 	    selection_t               selection;
 	    
-	    SigC::Connection   edited_widget_changed_conn;
+	    sigc::connection   edited_widget_changed_conn;
 	    
 	    FooCanvasmm::Item *canvas_overlay;
 	    Widgets::Type      palette_selection;
