@@ -1,4 +1,4 @@
-//$Id: guikachu2rcp.cc,v 1.10 2004/08/20 19:07:32 cactus Exp $ -*- c++ -*-
+//$Id: guikachu2rcp.cc,v 1.11 2004/09/23 16:21:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,7 +19,9 @@
 #include "config.h"
 #include "gnome-i18n-cnp.h"
 
-#include <libgnomevfs/gnome-vfs.h>
+#include <glib.h>
+#include <libgnomevfsmm/init.h>
+#include <gdkmm/wrap_init.h>
 
 #include "io/xml-loader.h"
 #include "io/rcp-saver.h"
@@ -91,10 +93,12 @@ int main (int argc, char **argv)
 {
 #ifdef ENABLE_NLS
     bindtextdomain (PACKAGE, GNOME_LOCALEDIR);
+    bind_textdomain_codeset (PACKAGE, "UTF-8");
     textdomain (PACKAGE);
 #endif
 
-    gnome_vfs_init ();
+    Gnome::Vfs::init ();
+    Gdk::wrap_init ();
     
     if (argc < 2)
     {
