@@ -1,4 +1,4 @@
-//$Id: io.cc,v 1.10 2004/08/20 18:22:17 cactus Exp $ -*- c++ -*-
+//$Id: io.cc,v 1.12 2004/09/25 08:46:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -57,16 +57,16 @@ Glib::ustring IO::get_mime_type (const Glib::ustring &uri) throw (Glib::Exceptio
     return file_info->get_mime_type ();
 }
 
-void IO::load_uri (const Glib::ustring &uri, char *&data, Gnome::Vfs::FileSize &len) throw (Glib::Exception)
+void IO::load_uri (const Glib::ustring &uri, unsigned char *&data, Gnome::Vfs::FileSize &len) throw (Glib::Exception)
 {
     Gnome::Vfs::Handle f;
     f.open (uri, Gnome::Vfs::OPEN_READ);
 
     Glib::RefPtr<Gnome::Vfs::FileInfo> vfs_info = f.get_file_info (Gnome::Vfs::FILE_INFO_FOLLOW_LINKS);
         
-    data = new char[vfs_info->get_size ()];
+    data = new unsigned char[vfs_info->get_size ()];
     len = 0;        
-    char                 buffer[10240];
+    unsigned char        buffer[10240];
     Gnome::Vfs::FileSize bytes_read;
 
     do {
@@ -77,11 +77,11 @@ void IO::load_uri (const Glib::ustring &uri, char *&data, Gnome::Vfs::FileSize &
     } while (bytes_read);
 }
 
-void IO::save_uri (const Glib::ustring &uri, const char *data, Gnome::Vfs::FileSize len) throw (Glib::Exception)
+void IO::save_uri (const Glib::ustring &uri, const unsigned char *data, Gnome::Vfs::FileSize len) throw (Glib::Exception)
 {
     // Create file
     Gnome::Vfs::Handle f;
-    f.create (uri, Gnome::Vfs::OPEN_WRITE, 0, 06444);
+    f.create (uri, Gnome::Vfs::OPEN_WRITE, 0, 0644);
 	
     // Write data to VFS stream
     const Gnome::Vfs::FileSize chunk_size = len;
