@@ -1,4 +1,4 @@
-//$Id: rcp-loader.cc,v 1.8 2004/09/11 14:50:39 cactus Exp $ -*- c++ -*-
+//$Id: rcp-loader.cc,v 1.9 2004/09/25 08:46:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,7 +44,7 @@ namespace
 void RCPLoader::load (ResourceManager *manager, const Glib::ustring &uri) throw (Glib::Exception)
 {
     // Load data from URI
-    char                 *data = 0;
+    unsigned char        *data = 0;
     Gnome::Vfs::FileSize  len;
 
     try {
@@ -56,7 +56,7 @@ void RCPLoader::load (ResourceManager *manager, const Glib::ustring &uri) throw
     }
 
     // Start the lexer
-    yy_buffer_state* lex_buffer = yy_scan_bytes (data, len);
+    yy_buffer_state* lex_buffer = yy_scan_bytes ((char*)data, len);
     delete[] data;
 
     // ...and the parser
