@@ -1,4 +1,4 @@
-//$Id: rcp-save-form.cc,v 1.16 2004/06/12 12:14:32 cactus Exp $ -*- c++ -*-
+//$Id: rcp-save-form.cc,v 1.18 2004/09/11 14:50:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,6 +27,7 @@
 #include "form-editor/checkbox.h"
 #include "form-editor/list.h"
 #include "form-editor/scrollbar.h"
+#include "form-editor/slider.h"
 #include "form-editor/text-field.h"
 #include "form-editor/table.h"
 #include "form-editor/popup-trigger.h"
@@ -57,6 +58,7 @@ namespace Guikachu
                 void visit_widget (Widgets::List            *widget);
                 void visit_widget (Widgets::PopupTrigger    *widget);
                 void visit_widget (Widgets::ScrollBar       *widget);
+                void visit_widget (Widgets::Slider          *widget);
                 void visit_widget (Widgets::TextField       *widget);
                 void visit_widget (Widgets::Table           *widget);
                 void visit_widget (Widgets::FormBitmap      *widget);
@@ -82,8 +84,17 @@ namespace
     template<class T>
     void save_element_pos_size (T *res, std::ostream &ostr)
     {
-        ostr << " AT (" << res->x     << " " << res->y      << " "
-             << res->width << " " << res->height << ")" << std::endl;
+        ostr << " AT (" << res->x << " " << res->y << " "
+             << res->get_width () << " " << res->get_height () << ")"
+             << std::endl;
+    }
+
+    template<>
+    void save_element_pos_size<Resources::Form> (Resources::Form *res, std::ostream &ostr)
+    {
+        ostr << " AT (" << res->x << " " << res->y << " "
+             << res->width << " " << res->height << ")"
+             << std::endl;
     }
     
     template<class T>
@@ -139,8 +150,8 @@ void RCPSaver_funcs::save_res_form (Resources::Form *res, std::ostream &ostr)
     save_element_pos_size (res, ostr);
     ostr << "USABLE" << std::endl;
 
-    save_flag (res->modal, ostr, "MODAL ");
-    save_flag (res->frame, ostr, "FRAME ", "NOFRAME ");
+    save_flag (res->modal, ostr,      "MODAL ");
+    save_flag (res->frame, ostr,      "FRAME ", "NOFRAME ");
     save_flag (res->savebehind, ostr, "SAVEBEHIND ", "NOSAVEBEHIND ");
 
     ostr << std::endl;
@@ -218,7 +229,8 @@ void RCP::WidgetSaver::visit_widget (Widgets::Button *widget)
     ostr << " FONT " << widget->font;
     ostr << " " << frame_str;
     ostr << " " << anchor_str;
-    save_flag (widget->usable, ostr, " USABLE", " NONUSABLE");
+    save_flag (widget->usable, ostr,   " USABLE", " NONUSABLE");
+    save_flag (widget->disabled, ostr, " DISABLED");
     save_graphical (widget, ostr);
     
     ostr << std::endl;
@@ -231,7 +243,8 @@ void RCP::WidgetSaver::visit_widget (Widgets::PushButton *widget)
 
     ostr << " FONT " << widget->font;
     ostr << " GROUP " << widget->group;
-    save_flag (widget->usable, ostr, " USABLE", " NONUSABLE");
+    save_flag (widget->usable, ostr,   " USABLE", " NONUSABLE");
+    save_flag (widget->disabled, ostr, " DISABLED");
     save_graphical (widget, ostr);
     
     ostr << std::endl;
@@ -251,9 +264,10 @@ void RCP::WidgetSaver::visit_widget (Widgets::Checkbox *widget)
 
     ostr << " FONT " << widget->font;
     ostr << " GROUP " << widget->group;
-    save_flag (widget->usable, ostr, " USABLE", " NONUSABLE");
+    save_flag (widget->usable, ostr,       " USABLE", " NONUSABLE");
+    save_flag (widget->disabled, ostr,     " DISABLED");
     save_flag (widget->anchor_right, ostr, " RIGHTANCHOR", " LEFTANCHOR");
-    save_flag (widget->toggled, ostr, " CHECKED");
+    save_flag (widget->toggled, ostr,      " CHECKED");
     
     ostr << std::endl;
 }
@@ -291,7 +305,8 @@ void RCP::WidgetSaver::visit_widget (Widgets::SelectorTrigger *widget)
     save_element_pos_autosize (widget, ostr);
 
     ostr << " FONT " << widget->font;
-    save_flag (widget->usable, ostr, " USABLE", " NONUSABLE");
+    save_flag (widget->usable, ostr,       " USABLE", " NONUSABLE");
+    save_flag (widget->disabled, ostr,     " DISABLED");
     save_flag (widget->anchor_right, ostr, " RIGHTANCHOR", " LEFTANCHOR");
     save_graphical (widget, ostr);
     
@@ -304,7 +319,8 @@ void RCP::WidgetSaver::visit_widget (Widgets::PopupTrigger *widget)
     save_element_pos_autosize (widget, ostr);
 
     ostr << " FONT " << widget->font;
-    save_flag (widget->usable, ostr, " USABLE", " NONUSABLE");
+    save_flag (widget->usable, ostr,       " USABLE", " NONUSABLE");
+    save_flag (widget->disabled, ostr,     " DISABLED");
     save_flag (widget->anchor_right, ostr, " RIGHTANCHOR", " LEFTANCHOR");
     save_graphical (widget, ostr);
     
@@ -316,31 +332,40 @@ void RCP::WidgetSaver::visit_widget (Widgets::PopupTrigger *widget)
 
 void RCP::WidgetSaver::visit_widget (Widgets::ScrollBar *widget)
 {
-    gchar *width_str, *height_str;
-
-    width_str = g_strdup_printf ("%d", widget->get_width ());
-    height_str = g_strdup_printf ("%d", int (widget->height));
-
     ostr << "  SCROLLBAR ID " << widget->id;
-    ostr << " AT (" << widget->x << " " << widget->y
-	 << " " << width_str << " " << height_str << ")";
+    save_element_pos_size (widget, ostr);
 
     ostr << " VALUE "    << widget->value
 	 << " MIN "      << widget->min_value
 	 << " MAX "      << widget->max_value
 	 << " PAGESIZE " << widget->page_size;
     ostr << std::endl;
-    
-    g_free (height_str);
-    g_free (width_str);
+}
+
+void RCP::WidgetSaver::visit_widget (Widgets::Slider *widget)
+{
+    ostr << "  SLIDER ID " << widget->id;
+    save_element_pos_size (widget, ostr);
+
+    save_flag (widget->usable, ostr,   " USABLE", " NONUSABLE");
+    save_flag (widget->disabled, ostr, " DISABLED");
+
+    if (widget->thumb_id != "")
+	ostr << " THUMBID " << widget->thumb_id;
+   if (widget->background_id != "")
+	ostr << " BACKGROUNDID " << widget->background_id;
+
+    ostr << " VALUE "    << widget->value
+	 << " MIN "      << widget->min_value
+	 << " MAX "      << widget->max_value
+	 << " PAGESIZE " << widget->page_size
+	 << std::endl;
 }
 
 void RCP::WidgetSaver::visit_widget (Widgets::TextField *widget)
 {
-    gchar *width_str = 0, *height_str = 0;
+    gchar *height_str = 0;
 
-    width_str = g_strdup_printf ("%d", widget->get_width ());
-    
     if (widget->manual_height)
 	height_str = g_strdup_printf ("%d", int (widget->height));
     else
@@ -348,20 +373,20 @@ void RCP::WidgetSaver::visit_widget (Widgets::TextField *widget)
     
     ostr << "  FIELD ID " << widget->id;
     ostr << " AT (" << widget->x << " " << widget->y << " "
-	 << width_str << " " << height_str << ")";
-
+	 << widget->get_width () << " " << height_str << ")";
+    
     g_free (height_str);
-    g_free (width_str);
 
     ostr << " FONT " << widget->font;
-    save_flag (widget->usable, ostr, " USABLE", " NONUSABLE");
-    save_flag (widget->editable, ostr, " EDITABLE", " NONEDITABLE");
-    save_flag (widget->multi_line, ostr, " MULTIPLELINES", " SINGLELINE");
+    save_flag (widget->usable, ostr,        " USABLE", " NONUSABLE");
+    save_flag (widget->disabled, ostr,      " DISABLED");
+    save_flag (widget->editable, ostr,      " EDITABLE", " NONEDITABLE");
+    save_flag (widget->multi_line, ostr,    " MULTIPLELINES", " SINGLELINE");
     save_flag (widget->justify_right, ostr, " RIGHTALIGN", " LEFTALIGN");
-    save_flag (widget->underline, ostr, " UNDERLINED");
-    save_flag (widget->dynamic_size, ostr, " DYNAMICSIZE");
-    save_flag (widget->auto_shift, ostr, " AUTOSHIFT");
-    save_flag (widget->numeric, ostr, " NUMERIC");
+    save_flag (widget->underline, ostr,     " UNDERLINED");
+    save_flag (widget->dynamic_size, ostr,  " DYNAMICSIZE");
+    save_flag (widget->auto_shift, ostr,    " AUTOSHIFT");
+    save_flag (widget->numeric, ostr,       " NUMERIC");
     save_flag (widget->has_scrollbar, ostr, " HASSCROLLBAR");
 
     if (widget->max_length)
