@@ -1,4 +1,4 @@
-//$Id: res-bitmap.cc,v 1.8 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: res-bitmap.cc,v 1.11 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,9 @@
 
 #include "io/storage-processor.h"
 #include "io/storage-node-handlers.h"
+#include "io/base64.h"
+
+#include <gdkmm/pixbufloader.h>
 
 using namespace Guikachu::IO::XML;
 
@@ -57,12 +60,16 @@ void BitmapIOAdaptor::load (const StorageNode &node)
 
     processor.run (node);
 
-    try
-    {
-        Magick::Blob blob;
-        blob.base64 (image_data_base64_prop);
-        res->set_image (blob);
-    } catch (...) {}
+    // Load image data from base64 encoded string
+    unsigned char *data = 0;
+    size_t len;
+    
+    if (image_data_base64_prop == "")
+	return;
+    
+    IO::Base64::decode (image_data_base64_prop, data, len);
+    res->load_data (data, len);
+    delete[] data;
 }
 
 void BitmapIOAdaptor::save (StorageNode &node)
@@ -92,15 +99,19 @@ void BitmapIOAdaptor::save (StorageNode &node)
     }
 
     node.set_prop ("type", type_str);
+
+    unsigned char *pixbuf_buf = 0;
+    size_t         pixbuf_len;
     
-    const Magick::Image &image = res->get_image ();
-    if (!image.isValid ())
-        return;
-    
-    Magick::Blob blob;
-    
-    // Magick::Image::write is not a const method
-    const_cast<Magick::Image&>(image).write (&blob);
-    
-    node.add_node ("image_data", blob.base64 ()).set_prop ("encoding", "base64");
+    try {
+        res->save_data_png (pixbuf_buf, pixbuf_len);
+        
+        StorageNode image_node = node.add_node ("image_data", Base64::encode (pixbuf_buf, pixbuf_len));
+        image_node.set_prop ("encoding", "base64");
+        image_node.set_prop ("content-type", "image/png");
+
+        delete[] pixbuf_buf;
+    } catch (Glib::Exception &e) {
+        delete[] pixbuf_buf;
+    }
 }
