@@ -1,4 +1,4 @@
-//$Id: res-bitmapfamily.cc,v 1.4 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: res-bitmapfamily.cc,v 1.7 2004/12/06 16:27:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,6 +20,7 @@
 
 #include "io/storage-processor.h"
 #include "io/storage-node-handlers.h"
+#include "io/base64.h"
 
 #include <glib.h> // for g_warning
 
@@ -70,13 +71,12 @@ void BitmapFamilyIOAdaptor::load (const StorageNode &node)
                 continue;
             }
 
+	    unsigned char *data;
+	    size_t len;
             std::string image_data = image_node.get_content_raw ();
-            try
-            {
-                Magick::Blob blob;
-                blob.base64 (image_data);
-                res->set_image (static_cast<Resources::Bitmap::BitmapType>(bitmap_type), blob);
-            } catch (...) {}
+	    IO::Base64::decode (image_data, data, len);
+	    res->load_data (static_cast<Resources::Bitmap::BitmapType> (bitmap_type), data, len);
+	    delete[] data;
         }
     }
 }
@@ -97,18 +97,25 @@ void BitmapFamilyIOAdaptor::save_bitmap (StorageNode                   &parent_n
                                          Resources::Bitmap::BitmapType  type)
 {
     std::string type_name = bitmap_type_to_string (type);
-    const Magick::Image &image = res->get_image (type);
-    if (!image.isValid ())
-        return;
-
-    Magick::Blob blob;
     
-    // Magick::Image::write is not a const method
-    const_cast<Magick::Image&>(image).write (&blob);
+    unsigned char *pixbuf_buf;
+    size_t pixbuf_len;
 
-    StorageNode node = parent_node.add_node ("image_data", blob.base64 ());
-    node.set_prop ("type", type_name);
-    node.set_prop ("encoding", "base64");
+    try {
+        res->save_data_png (type, pixbuf_buf, pixbuf_len);
+
+        if (!pixbuf_buf)
+            return;
+        
+        StorageNode image_node = parent_node.add_node ("image_data", Base64::encode (pixbuf_buf, pixbuf_len));
+        image_node.set_prop ("encoding", "base64");
+        image_node.set_prop ("content-type", "image/png");
+        image_node.set_prop ("type", type_name);
+
+        delete[] pixbuf_buf;
+    } catch (Glib::Exception &e) {
+        delete[] pixbuf_buf;
+    }
 }
 
 namespace
