@@ -1,4 +1,4 @@
-//$Id: widget-pushbutton.cc,v 1.4 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: widget-pushbutton.cc,v 1.5 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,6 +38,7 @@ void PushButtonIOAdaptor::load (const StorageNode &node)
     processor.add_handler ("image",          new StorageNodeHandlers::StringProp ("id", widget->bitmap_id));
     processor.add_handler ("selected_image", new StorageNodeHandlers::StringProp ("id", widget->selected_bitmap_id));
     processor.add_handler ("usable",         new StorageNodeHandlers::Flag (widget->usable));
+    processor.add_handler ("disabled",       new StorageNodeHandlers::Flag (widget->disabled));
     processor.add_handler ("anchor_right",   new StorageNodeHandlers::Flag (widget->anchor_right));
     processor.add_handler ("group",          new StorageNodeHandlers::IntProp ("id", widget->group));
     
@@ -51,6 +52,8 @@ void PushButtonIOAdaptor::save (StorageNode &node)
     /* Usable */
     if (widget->usable)
 	node.add_node ("usable");
+    if (widget->disabled)
+	node.add_node ("disabled");
 
     /* Label and font */
     save_widget_text (widget, node);
