@@ -1,4 +1,4 @@
-//$Id: widget-selector-trigger.cc,v 1.3 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
+//$Id: widget-selector-trigger.cc,v 1.4 2004/09/08 10:16:20 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,6 +38,7 @@ void SelectorTriggerIOAdaptor::load (const StorageNode &node)
     processor.add_handler ("image",          new StorageNodeHandlers::StringProp ("id", widget->bitmap_id));
     processor.add_handler ("selected_image", new StorageNodeHandlers::StringProp ("id", widget->selected_bitmap_id));
     processor.add_handler ("usable",         new StorageNodeHandlers::Flag (widget->usable));
+    processor.add_handler ("disabled",       new StorageNodeHandlers::Flag (widget->disabled));
     processor.add_handler ("anchor_right",   new StorageNodeHandlers::Flag (widget->anchor_right));
 
     processor.run (node);
@@ -50,6 +51,8 @@ void SelectorTriggerIOAdaptor::save (StorageNode &node)
     /* Usable */
     if (widget->usable)
 	node.add_node ("usable");
+    if (widget->disabled)
+	node.add_node ("disabled");
 
     /* Anchor_right */
     if (widget->anchor_right)
