@@ -1,6 +1,6 @@
-//$Id: menu-res.cc,v 1.28 2004/01/30 01:08:56 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.cc,v 1.30 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -22,7 +22,7 @@ using namespace Guikachu;
 using namespace Guikachu::Resources;
 
 Menu::Submenu::Submenu (const std::string &label_) :
-    label (make_7bit_string (label_))
+    label (convert_to_ascii (label_))
 {
 }
 
@@ -36,7 +36,6 @@ Menu::Menu (ResourceManager   *manager,
 
 Menu::~Menu ()
 {
-    deregister_menu ();
 }
 
 void Menu::register_menu (const MenuTree &new_submenus)
@@ -45,12 +44,12 @@ void Menu::register_menu (const MenuTree &new_submenus)
     
     for (MenuTree::iterator i = submenus.begin (); i != submenus.end (); ++i)
     {
-	for (std::vector<MenuItem>::iterator j = i->items.begin (); j != i->items.end (); ++j)
+	for (MenuItems::iterator j = i->items.begin (); j != i->items.end (); ++j)
 	{
 	    if (!j->separator)
 	    {
-		j->id = make_7bit_string (j->id);
-		j->label = make_7bit_string (j->label);
+		j->id = convert_to_ascii (j->id);
+		j->label = convert_to_ascii (j->label);
 		
 		if (!register_id (j->id))
 		{
@@ -66,7 +65,7 @@ void Menu::deregister_menu ()
 {
     for (MenuTree::const_iterator i = submenus.begin (); i != submenus.end (); ++i)
     {
-	for (std::vector<MenuItem>::const_iterator j = i->items.begin ();
+	for (MenuItems::const_iterator j = i->items.begin ();
 	     j != i->items.end (); ++j)
 	{
 	    if (!j->separator)
@@ -75,7 +74,7 @@ void Menu::deregister_menu ()
     }
 }
 
-void Menu::set_submenus (const std::vector<Menu::Submenu>& new_menu)
+void Menu::set_submenus (const Menu::MenuTree& new_menu)
 {
     deregister_menu ();
     register_menu (new_menu);
