@@ -1,4 +1,4 @@
-//$Id: preferences-win.cc,v 1.10 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: preferences-win.cc,v 1.11 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,8 +24,8 @@
 
 #include <gtkmm/adjustment.h>
 
-#include <sigc++/bind.h>
-#include <sigc++/hide.h>
+#include <sigc++/adaptors/bind.h>
+#include <sigc++/adaptors/hide.h>
 
 namespace {
     static std::string rgb_to_color (guint8 r, guint8 g, guint8 b);
@@ -52,29 +52,27 @@ GUI::PreferencesWin::PreferencesWin ():
     
     prop_box->set_title (_("Preferences"));
 
-    using namespace SigC;
-    
     // Set up 'changed' signals so that the 'Apply' button is made sensitive
     color_fg->signal_color_set ().connect (
-	slot (*this, &PreferencesWin::color_changed_cb));
+	sigc::mem_fun (*this, &PreferencesWin::color_changed_cb));
     color_disabled->signal_color_set ().connect (
-	slot (*this, &PreferencesWin::color_changed_cb));
+	sigc::mem_fun (*this, &PreferencesWin::color_changed_cb));
     color_bg->signal_color_set ().connect (
-	slot (*this, &PreferencesWin::color_changed_cb));
+	sigc::mem_fun (*this, &PreferencesWin::color_changed_cb));
     color_selection->signal_color_set ().connect (
-	slot (*this, &PreferencesWin::color_changed_cb));
+	sigc::mem_fun (*this, &PreferencesWin::color_changed_cb));
 
     spin_zoom->get_adjustment ()->signal_value_changed ().connect (
-	bind (slot (*this, &PreferencesWin::set_modified), true));
+	bind (sigc::mem_fun (*this, &PreferencesWin::set_modified), true));
     
     // Update controls when window's shown
-    prop_box->signal_show ().connect (SigC::slot (*this, &PreferencesWin::update));
+    prop_box->signal_show ().connect (sigc::mem_fun (*this, &PreferencesWin::update));
     
     // Set up buttons
-    apply_btn->signal_clicked ().connect (SigC::slot (*this, &PreferencesWin::apply_cb));
-    ok_btn->signal_clicked ().connect (SigC::slot (*this, &PreferencesWin::apply_cb));
-    ok_btn->signal_clicked ().connect (SigC::slot (*prop_box, &Gtk::Dialog::hide));
-    cancel_btn->signal_clicked ().connect (SigC::slot (*prop_box, &Gtk::Dialog::hide));
+    apply_btn->signal_clicked ().connect (sigc::mem_fun (*this, &PreferencesWin::apply_cb));
+    ok_btn->signal_clicked ().connect (sigc::mem_fun (*this, &PreferencesWin::apply_cb));
+    ok_btn->signal_clicked ().connect (sigc::mem_fun (*prop_box, &Gtk::Dialog::hide));
+    cancel_btn->signal_clicked ().connect (sigc::mem_fun (*prop_box, &Gtk::Dialog::hide));
 }
 
 void GUI::PreferencesWin::color_changed_cb (guint r, guint g, guint b, guint a)
