@@ -1,4 +1,4 @@
-//$Id: preferences.cc,v 1.14 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: preferences.cc,v 1.16 2004/07/12 22:07:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -91,7 +91,7 @@ std::string Preferences::get_gconf_string (const std::string &key)
 
 
 
-SigC::Signal0<void> Preferences::Interface::recent_files_changed;
+sigc::signal0<void> Preferences::Interface::recent_files_changed;
 
 static void Preferences::Interface::gconf_recent_files_cb (GConfClient  *client,
 							   unsigned int  conn_id,
@@ -108,36 +108,25 @@ Preferences::Interface::RecentFiles Preferences::Interface::get_recent_files ()
     GSList *gconf_list = gconf_client_get_list (gconf_client,
 						GCONF_ROOT "/Interface/recent_files",
 						GCONF_VALUE_STRING, 0);
-    GSList *gconf_mime_list = gconf_client_get_list (gconf_client,
-						     GCONF_ROOT "/Interface/recent_files_mime",
-						     GCONF_VALUE_STRING, 0);
-    
+
     for (GSList *i = gconf_list; i; i = g_slist_next (i))
-    {
-	RecentFileEntry e ((char*)i->data, "application/x-guikachu");
-	if (gconf_mime_list)
-	{
-	    e.second = (char*)gconf_mime_list->data;
-	    gconf_mime_list = g_slist_next (gconf_mime_list);
-	}
-	retval.push_back (e);
-    }
+        retval.push_back ((char*)i->data);
 
     return retval;
 }
 
-void Preferences::Interface::add_recent_file (const RecentFileEntry &entry)
+void Preferences::Interface::add_recent_file (const Glib::ustring &uri)
 {
     RecentFiles recent_list = get_recent_files ();
 
     // Remove latest addition from list
     RecentFiles::iterator old_pos =
-	std::find (recent_list.begin (), recent_list.end (), entry);
+	std::find (recent_list.begin (), recent_list.end (), uri);
     if (old_pos != recent_list.end ())
 	recent_list.erase (old_pos);
 
     // Prepend latest addition to list
-    recent_list.push_front (entry);
+    recent_list.push_front (uri);
     
     // Truncate list
     int recent_list_size = gconf_client_get_int (
@@ -155,26 +144,18 @@ void Preferences::Interface::add_recent_file (const RecentFileEntry &entry)
 
     // Save new list in GConf
     GSList *c_recent_list = 0, *c_i = 0;
-    GSList *c_mime_list = 0, *c_mime_i = 0;
     for (RecentFiles::const_iterator i = recent_list.begin (); i != recent_list.end (); i++)
     {
 	if (!c_recent_list)
-	{
-	    c_recent_list = c_i = g_slist_append (c_i, (void*)(i->first.c_str ()));
-	    c_mime_list = c_mime_i = g_slist_append (c_mime_i, (void*)(i->second.c_str ()));
-	} else {
-	    c_i = g_slist_append(c_i, (void*)(i->first.c_str ()));
-	    c_mime_i = g_slist_append(c_mime_i, (void*)(i->second.c_str ()));
-	}
+	    c_recent_list = c_i = g_slist_append (c_i, (void*)(i->c_str ()));
+	else
+	    c_i = g_slist_append (c_i, (void*)(i->c_str ()));
     }
 
     gconf_client_set_list (gconf_client, GCONF_ROOT "/Interface/recent_files",
 			   GCONF_VALUE_STRING, c_recent_list, 0); 
-    gconf_client_set_list (gconf_client, GCONF_ROOT "/Interface/recent_files_mime",
-			   GCONF_VALUE_STRING, c_mime_list, 0); 
 
     g_slist_free (c_recent_list);
-    g_slist_free (c_mime_list);
 }
 
 int Preferences::Interface::get_undo_size ()
@@ -184,7 +165,7 @@ int Preferences::Interface::get_undo_size ()
 
 
 
-SigC::Signal0<void> Preferences::FormEditor::colors_changed;
+sigc::signal0<void> Preferences::FormEditor::colors_changed;
 
 void Preferences::FormEditor::set_colors (const std::string &color_fg,
 					  const std::string &color_disabled,
