@@ -1,4 +1,4 @@
-//$Id: property-ops-widget.h,v 1.8 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: property-ops-widget.h,v 1.9 2004/08/17 18:42:35 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -80,8 +80,8 @@ namespace Guikachu
 		property_t &prop = prop_holder.get_member (*widget);
 	    
 		PropChangeOp<value_t> *new_op = new PropChangeOp<value_t> (
-		    label, widget, prop, op->new_val, true);
-		new_op->old_val = old_val;
+		    this->label, widget, prop, op->new_val, true);
+		new_op->old_val = this->old_val;
 
 		return new_op;
 	    }
