@@ -1,4 +1,4 @@
-//$Id: queued-signal.h,v 1.5 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: queued-signal.h,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  *
@@ -22,15 +22,15 @@
 #define GUIKACHU_QUEUED_SIGNAL_H
 
 #include "vsignal.h"
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 
 namespace Guikachu
 {
     class QueuedSignal: public VSignal,
-			public SigC::Object
+			public sigc::trackable
     {
 	bool queued;
-	typedef void (*signal_queuer_t) (SigC::Slot0<void>);
+	typedef void (*signal_queuer_t) (slot_t);
 	static signal_queuer_t signal_queuer;
 	
     public:
