@@ -1,4 +1,4 @@
-//$Id: resource-tree-treedata.cc,v 1.1 2004/07/07 19:03:46 cactus Exp $ -*- c++ -*-
+//$Id: resource-tree-treedata.cc,v 1.2 2004/08/14 15:35:35 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -110,24 +110,22 @@ void ResourceTree::TreeData::apply_to_cell (Gtk::CellRenderer *cell) const
     CellRendererIconText *cell_icontext = dynamic_cast<CellRendererIconText*> (cell);
     g_return_if_fail (cell_icontext);
 
-    Gtk::CellRendererText &cell_text = cell_icontext->get_text_cell ();
-    
-    cell_text.property_text () = get_label ();
+    cell_icontext->property_text () = get_label ();
 
     switch (type)
     {
     case TREEDATA_CATEGORY:
-        cell_text.property_weight () = Pango::WEIGHT_BOLD;
+        cell_icontext->property_weight () = Pango::WEIGHT_BOLD;
         cell_icontext->property_pixbuf () = Glib::RefPtr<Gdk::Pixbuf> ();
         //cell_icontext->property_editable () = false;
         break;
     case TREEDATA_APP:
-        cell_text.property_weight () = Pango::WEIGHT_BOLD;
+        cell_icontext->property_weight () = Pango::WEIGHT_BOLD;
         cell_icontext->property_pixbuf () = Glib::RefPtr<Gdk::Pixbuf> ();
         //cell_icontext->property_editable () = true;
         break;
     case TREEDATA_RESOURCE:
-        cell_text.property_weight () = Pango::WEIGHT_NORMAL;
+        cell_icontext->property_weight () = Pango::WEIGHT_NORMAL;
         cell_icontext->property_pixbuf () = Resources::get_type_pixbuf (res->get_type ());
         //cell_icontext->property_editable () = true;
         break;
