@@ -1,4 +1,4 @@
-//$Id: storage.cc,v 1.14 2004/08/20 18:22:17 cactus Exp $ -*- c++ -*-
+//$Id: storage.cc,v 1.15 2004/09/25 08:46:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -116,8 +116,8 @@ void Storage::save_uri (const Glib::ustring &uri) const throw (Glib::Exception)
 {
     g_assert (doc != 0);
 
-    char *buffer = 0;
-
+    unsigned char *buffer = 0;
+    
     try {
         Gnome::Vfs::FileSize buffer_size;
         
@@ -132,12 +132,11 @@ void Storage::save_uri (const Glib::ustring &uri) const throw (Glib::Exception)
     }
 }
 
-void Storage::save_buffer (char *&buffer, Gnome::Vfs::FileSize &buffer_size) const
+void Storage::save_buffer (unsigned char *&buffer, Gnome::Vfs::FileSize &buffer_size) const
 {
-    xmlChar **buffer_addr = &reinterpret_cast<xmlChar*&>(buffer);
     int buffer_size_tmp;
     
-    xmlDocDumpMemory (doc, buffer_addr, &buffer_size_tmp);
+    xmlDocDumpMemory (doc, &buffer, &buffer_size_tmp);
     buffer_size = buffer_size_tmp;
 }
 
