@@ -1,4 +1,4 @@
-//$Id: vsignal.h,v 1.5 2004/06/10 15:51:15 cactus Exp $ -*- c++ -*-
+//$Id: vsignal.h,v 1.6 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  *
@@ -25,7 +25,7 @@
 
 namespace Guikachu
 {
-    /* This is a SigC::Signal0<void> wrapper that has only one
+    /* This is a sigc::signal0<void> wrapper that has only one
        difference from the real McCoy: its emit() member function is
        virtual and thus can be overwritten.
        This is done by QueuedSignal to queue up emission requests and
@@ -35,19 +35,23 @@ namespace Guikachu
     
     class VSignal
     {
-    private:
-	typedef SigC::Signal0<void>       real_signal_t;
-	typedef real_signal_t::InSlotType slot_t;
+    public:
+	typedef sigc::signal0<void>      real_signal_t;
+	typedef real_signal_t::slot_type slot_t;
+        typedef real_signal_t::iterator  connection_t;
 
+        typedef sigc::bound_const_mem_functor0<void, real_signal_t> signal_slot_t;
+
+    private:
 	real_signal_t real_signal;
 	
     public:
 	VSignal ()          {};
 	virtual ~VSignal () {};
 
-	SigC::Connection connect (const slot_t &s);
+	connection_t connect (const slot_t &s);
 
-	virtual SigC::Slot0<void> slot ();
+        virtual signal_slot_t make_slot() const;
 	virtual void emit ();
 	void operator() () { emit (); };
     };
