@@ -1,6 +1,6 @@
-//$Id: string-list-ops-priv-resource.cc,v 1.2 2003/06/30 14:08:00 cactus Exp $ -*- c++ -*-
+//$Id: string-list-ops-priv-resource.cc,v 1.4 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -23,9 +23,9 @@
 using namespace Guikachu::ResourceOps::StringListOps;
 using namespace Guikachu;
 
-OpBase::OpBase (const std::string &op_label,
-		Resource          *resource,
-		property_t        &prop) :
+OpBase::OpBase (const Glib::ustring &op_label,
+		Resource            *resource,
+		property_t          &prop) :
     Guikachu::StringListOps::OpBase (op_label),
     manager (resource->get_manager ()),
     prop_holder (*resource, prop),
@@ -46,54 +46,54 @@ OpBase::property_t & OpBase::get_prop () const
     return prop_holder.get_member (*get_resource ());
 }
 
-AddOp::AddOp (const std::string &op_label,
-	      Resource          *resource,
-	      property_t        &prop,
-	      index_t            index,
-	      const std::string &item) :
+AddOp::AddOp (const Glib::ustring &op_label,
+	      Resource            *resource,
+	      property_t          &prop,
+	      index_t              index,
+	      const std::string   &item) :
     Guikachu::StringListOps::OpBase (op_label),
     OpBase (op_label, resource, prop),
     Guikachu::StringListOps::AddOp (op_label, index, item)
 {
 }
 
-RemoveOp::RemoveOp (const std::string &op_label,
-		    Resource          *resource,
-		    property_t        &prop,
-		    index_t            old_pos) :
+RemoveOp::RemoveOp (const Glib::ustring &op_label,
+		    Resource            *resource,
+		    property_t          &prop,
+		    index_t              old_pos) :
     Guikachu::StringListOps::OpBase (op_label),
     OpBase (op_label, resource, prop),
     Guikachu::StringListOps::RemoveOp (op_label, old_pos, prop()[old_pos])
 {
 }
 
-ChangeOp::ChangeOp (const std::string &op_label,
-		    Resource          *resource,
-		    property_t        &prop,
-		    index_t            index,
-		    const std::string &item) :
+ChangeOp::ChangeOp (const Glib::ustring &op_label,
+		    Resource            *resource,
+		    property_t          &prop,
+		    index_t              index,
+		    const std::string   &item) :
     Guikachu::StringListOps::OpBase (op_label),
     OpBase (op_label, resource, prop),
     Guikachu::StringListOps::ChangeOp (op_label, index, prop()[index], item)
 {
 }
 
-MoveOp::MoveOp (const std::string &op_label,
-		Resource          *resource,
-		property_t        &prop,
-		index_t            old_index,
-		index_t            new_index) :
+MoveOp::MoveOp (const Glib::ustring &op_label,
+		Resource            *resource,
+		property_t          &prop,
+		index_t              old_index,
+		index_t              new_index) :
     Guikachu::StringListOps::OpBase (op_label),
     OpBase (op_label, resource, prop),
     Guikachu::StringListOps::MoveOp (op_label, old_index, new_index)
 {
 }
 
-MoveOp::MoveOp (const std::string  &op_label,
-		Resource           *resource,
-		property_t         &prop,
-		const index_list_t &index_history_head,
-		const index_list_t &index_history_tail) :
+MoveOp::MoveOp (const Glib::ustring &op_label,
+		Resource            *resource,
+		property_t          &prop,
+		const index_list_t  &index_history_head,
+		const index_list_t  &index_history_tail) :
     Guikachu::StringListOps::OpBase (op_label),
     OpBase (op_label, resource, prop),
     Guikachu::StringListOps::MoveOp (op_label, index_history_head, index_history_tail)
