@@ -1,6 +1,6 @@
-//$Id: string-list-ops-priv.cc,v 1.2 2003/06/30 14:08:00 cactus Exp $ -*- c++ -*-
+//$Id: string-list-ops-priv.cc,v 1.4 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -23,9 +23,9 @@
 using namespace Guikachu;
 using namespace Guikachu::StringListOps;
 
-AddOp::AddOp (const std::string &op_label,
-	      index_t            index_,
-	      const std::string &item_) :
+AddOp::AddOp (const Glib::ustring &op_label,
+	      index_t              index_,
+	      const std::string   &item_) :
     OpBase (op_label),
     index (index_),
     item (item_)
@@ -56,9 +56,9 @@ void AddOp::redo ()
 
 
 
-RemoveOp::RemoveOp (const std::string &op_label,
-		    index_t            old_pos_,
-		    const std::string &old_item_) :
+RemoveOp::RemoveOp (const Glib::ustring &op_label,
+		    index_t              old_pos_,
+		    const std::string   &old_item_) :
     OpBase (op_label),
     old_pos (old_pos_),
     old_item (old_item_)
@@ -85,10 +85,10 @@ void RemoveOp::redo ()
 
 
 
-ChangeOp::ChangeOp (const std::string &op_label,
-		    index_t            index_,
-		    const std::string &old_item_,
-		    const std::string &new_item_) :
+ChangeOp::ChangeOp (const Glib::ustring &op_label,
+		    index_t              index_,
+		    const std::string   &old_item_,
+		    const std::string   &new_item_) :
     OpBase (op_label),
     index (index_),
     old_item (old_item_),
@@ -116,18 +116,18 @@ void ChangeOp::redo ()
 
 
 
-MoveOp::MoveOp (const std::string &op_label,
-		index_t            old_index,
-		index_t            new_index) :
+MoveOp::MoveOp (const Glib::ustring &op_label,
+		index_t              old_index,
+		index_t              new_index) :
     OpBase (op_label)
 {
     index_history.push_back (old_index);
     index_history.push_back (new_index);
 }
 
-MoveOp::MoveOp (const std::string  &op_label,
-		const index_list_t &index_history_head,
-		const index_list_t &index_history_tail) :
+MoveOp::MoveOp (const Glib::ustring  &op_label,
+		const index_list_t   &index_history_head,
+		const index_list_t   &index_history_tail) :
     OpBase (op_label),
     index_history (index_history_head)
 {
