@@ -1,6 +1,6 @@
-//$Id: string-list-ops-priv.h,v 1.2 2003/06/30 14:08:00 cactus Exp $ -*- c++ -*-
+//$Id: string-list-ops-priv.h,v 1.4 2004/06/10 15:51:16 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -32,15 +32,15 @@ namespace Guikachu
 	    typedef Property<value_t>        property_t;
 	    typedef unsigned int             index_t;
 
-	    std::string op_label;
+	    Glib::ustring op_label;
 
-	    OpBase (const std::string &op_label_) :
+	    OpBase (const Glib::ustring &op_label_) :
 		op_label (op_label_) {};
 
 	    virtual property_t & get_prop () const = 0;
 	    
 	public:
-	    std::string get_label () const { return op_label; };
+	    Glib::ustring get_label () const { return op_label; };
 	};
 	
 	class RemoveOp: public virtual OpBase
@@ -49,9 +49,9 @@ namespace Guikachu
 	    index_t     old_pos;
 	    std::string old_item;
 	    
-	    RemoveOp (const std::string &op_label,
-		      index_t            old_pos,
-		      const std::string &old_item);
+	    RemoveOp (const Glib::ustring &op_label,
+		      index_t              old_pos,
+		      const std::string   &old_item);
 	    
 	public:
 	    void undo ();
@@ -64,9 +64,9 @@ namespace Guikachu
 	    index_t     index;
 	    std::string item;
 	    
-	    AddOp (const std::string &op_label,
-		   index_t            index,
-		   const std::string &item);
+	    AddOp (const Glib::ustring &op_label,
+		   index_t              index,
+		   const std::string   &item);
 	    
 	public:
 	    void undo ();
@@ -79,10 +79,10 @@ namespace Guikachu
 	    index_t     index;
 	    std::string old_item, new_item;
 
-	    ChangeOp (const std::string &op_label,
-		      index_t            index,
-		      const std::string &old_item,
-		      const std::string &new_item);
+	    ChangeOp (const Glib::ustring &op_label,
+		      index_t              index,
+		      const std::string   &old_item,
+		      const std::string   &new_item);
 	    
 	public:
 	    void undo ();
@@ -96,13 +96,13 @@ namespace Guikachu
 	    
 	    index_list_t index_history;
 	    
-	    MoveOp (const std::string  &op_label,
-		    const index_list_t &index_history_head,
-		    const index_list_t &index_history_tail);
+	    MoveOp (const Glib::ustring &op_label,
+		    const index_list_t  &index_history_head,
+		    const index_list_t  &index_history_tail);
 	    
-	    MoveOp (const std::string &op_label,
-		    index_t            old_index,
-		    index_t            new_index);
+	    MoveOp (const Glib::ustring &op_label,
+		    index_t              old_index,
+		    index_t              new_index);
 	    
 	public:
 	    void undo ();
