@@ -1,4 +1,4 @@
-//$Id: target-combo.h,v 1.11 2004/06/25 17:15:34 cactus Exp $ -*- c++ -*-
+//$Id: target-combo.h,v 1.12 2004/08/31 12:50:40 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,7 +19,9 @@
 #ifndef GUIKACHU_WIDGETS_TARGET_COMBO_H
 #define GUIKACHU_WIDGETS_TARGET_COMBO_H
 
-#include <gtkmm/optionmenu.h>
+#include <gtkmm/combobox.h>
+#include <gtkmm/liststore.h>
+
 #include "property-editor.h"
 #include "resource-manager.h"
 #include <map>
@@ -31,13 +33,19 @@ namespace Guikachu
 	namespace PropertyEditors
 	{
 	    class TargetCombo: public PropertyEditor,
-			       public Gtk::OptionMenu
+			       public Gtk::ComboBox
 	    {
 		ResourceManager *manager;
 		Target          *target;
 		
 		std::map<Target::stock_id_t, int> stock_target_to_menuitem;
 		int                               num_targets;
+
+                Gtk::TreeModelColumn<Target::stock_id_t>   col_id;
+                Gtk::TreeModelColumn<Target::stock_desc_t> col_label;
+
+                Glib::RefPtr<Gtk::ListStore> store;
+
 	    public:
 		TargetCombo (ResourceManager *manager);
 
@@ -45,10 +53,10 @@ namespace Guikachu
 		sigc::signal0<void> stock_selected;
 		
 	    private:
+                bool update_block;
 		void update ();
 
-		void target_stock_cb (Target::stock_id_t stock_id);
-                void target_custom_cb ();
+		void changed_cb ();
 	    };
 	}
     }
